@@ -404,7 +404,7 @@ gdm_display_get_timed_login_details (GdmDisplay *self,
         gboolean res;
         gboolean enabled;
         int      delay;
-        char    *username;
+        char    *username = NULL;
 
         enabled = FALSE;
         username = NULL;
@@ -473,11 +473,16 @@ gdm_display_get_timed_login_details (GdmDisplay *self,
                 *delayp = delay;
         }
 
-        g_debug ("GdmDisplay: Got timed login details for display %s: %d '%s' %d",
-                 self->priv->x11_display_name,
-                 enabled,
-                 username,
-                 delay);
+        if (enabled) {
+                g_debug ("GdmDisplay: Got timed login details for display %s: %d %s %d",
+                         self->priv->x11_display_name,
+                         enabled,
+                         username,
+                         delay);
+        } else {
+                g_debug ("GdmDisplay: Got timed login details for display %s: 0",
+                         self->priv->x11_display_name);
+        }
 }
 
 gboolean
@@ -1215,10 +1220,10 @@ gdm_display_dispose (GObject *object)
         }
         g_clear_object (&self->priv->launch_environment);
 
-        g_assert (self->priv->status == GDM_DISPLAY_FINISHED ||
-                  self->priv->status == GDM_DISPLAY_FAILED);
-        g_assert (self->priv->user_access_file == NULL);
-        g_assert (self->priv->access_file == NULL);
+        g_warn_if_fail (self->priv->status != GDM_DISPLAY_PREPARED);
+        g_warn_if_fail (self->priv->status != GDM_DISPLAY_MANAGED);
+        g_warn_if_fail (self->priv->user_access_file == NULL);
+        g_warn_if_fail (self->priv->access_file == NULL);
 
         G_OBJECT_CLASS (gdm_display_parent_class)->dispose (object);
 }
