@@ -1505,6 +1505,7 @@ set_up_greeter_session (GdmManager *manager,
                  gdm_display_set_up_greeter_session (display, &allowed_user);
         } else {
                  g_object_set (G_OBJECT (display), "session-class", "user", NULL);
+                 g_object_set (G_OBJECT (display), "session-type", NULL, NULL);
                  allowed_user = g_strdup ("root");
         }
 
@@ -1549,12 +1550,6 @@ on_display_status_changed (GdmDisplay *display,
         switch (status) {
                 case GDM_DISPLAY_PREPARED:
                 case GDM_DISPLAY_MANAGED:
-#ifdef WITH_PLYMOUTH
-                        if (quit_plymouth) {
-                                plymouth_quit_with_transition ();
-                                manager->priv->plymouth_is_running = FALSE;
-                        }
-#endif
                         if ((display_number == -1 && status == GDM_DISPLAY_PREPARED) ||
                             (display_number != -1 && status == GDM_DISPLAY_MANAGED)) {
                                 char *session_class;
@@ -1568,6 +1563,12 @@ on_display_status_changed (GdmDisplay *display,
                         }
 
                         if (status == GDM_DISPLAY_MANAGED) {
+#ifdef WITH_PLYMOUTH
+                                if (quit_plymouth) {
+                                        plymouth_quit_with_transition ();
+                                        manager->priv->plymouth_is_running = FALSE;
+                                }
+#endif
                                 maybe_start_pending_initial_login (manager, display);
                         }
                         break;
@@ -2170,6 +2171,7 @@ start_autologin_conversation_if_necessary (GdmManager *manager,
 {
         gboolean enabled;
         int delay = 0;
+        gboolean is_initial = FALSE;
 
         gdm_display_get_timed_login_details (display, &enabled, NULL, &delay);
 
@@ -2181,6 +2183,9 @@ start_autologin_conversation_if_necessary (GdmManager *manager,
                 return;
         }
 
+        g_object_get (G_OBJECT (display), "is-initial", &is_initial, NULL);
+        g_object_set (G_OBJECT (session), "display-is-initial", is_initial, NULL);
+
         g_debug ("GdmManager: Starting automatic login conversation");
         gdm_session_start_conversation (session, "gdm-autologin");
 }
@@ -2211,8 +2216,8 @@ clean_embryonic_user_session (GdmSession *session)
 
 static void
 create_embryonic_user_session_for_display (GdmManager *manager,
-                                 GdmDisplay *display,
-                                 uid_t       allowed_user)
+                                           GdmDisplay *display,
+                                           uid_t       allowed_user)
 {
         GdmSession *session;
         gboolean    display_is_local = FALSE;
@@ -2651,10 +2656,8 @@ finish_display (const char *id,
                 GdmDisplay *display,
                 GdmManager *manager)
 {
-        if (gdm_display_get_status (display) != GDM_DISPLAY_MANAGED)
-                return;
-
-        gdm_display_unmanage (display);
+        if (gdm_display_get_status (display) == GDM_DISPLAY_MANAGED)
+                gdm_display_unmanage (display);
         gdm_display_finish (display);
 }
 
